@@ -258,7 +258,90 @@ def assignment_hash(ids, holeIDs):
     return assign_hash
 
 
-def make_design_assignments_targetdb(plan, fieldid, exposure,
+def designToField_exists(design_id, field_id, plan):
+    """
+    Check if designToField entry already exists to
+    to ensure unique entries (i.e. one unqiue
+    combo of design_id, field_id and version)
+
+    Parameters
+    ----------
+    design_id: int
+        design_id for the design
+
+    field_id: int
+        field_id for the design
+
+    plan: str or targetdb.Version instance
+        Either robostratgegy plan as a str or a targetdb.Version.get
+        instance for the plan that can be used to get the version pk
+
+    Returns
+    -------
+    exists: boolean
+        whether or not the combo of design_id, field_id and version
+        already exists in targetdb
+    """
+    # get the version pk based on the plan
+    if isinstance(plan, str):
+        versionDB = targetdb.Version()
+        verpk = versionDB.get(plan=plan).pk
+    else:
+        verpk = plan.pk
+
+    # create the query
+    check_designToField = (targetdb.DesignToField.select()
+                                                 .join(targetdb.Field)
+                                                 .where((targetdb.DesignToField.design == design_id) &
+                                                        (targetdb.Field.field_id == field_id) &
+                                                        (targetdb.Field.version == verpk)))
+    exists = check_designToField.exists()
+    return exists
+
+
+def make_designToField(design, fieldid, exposure, field_exposure):
+    """
+    Create a new designToField entry
+
+    Parameters
+    ----------
+    design: int or targetdb.Design instance
+        The design_id for the design (can be int or peewee
+        instance)
+
+    fieldid: int or targetdb.Field instance
+        The fieldid for the field (int) or a targetdb.Field
+        instance for the field that can be used to get the field pk
+
+    exposure: int
+        The exposure of this set of designs. 0th indexed
+
+    field_exposure: int
+        The exposure of this set of designs as listed in the
+        robostrategy design file. 0th indexed
+    """
+    # get the fieldpk
+    if isinstance(design, int):
+        design_id = design
+    else:
+        design_id = design.design_id
+
+    if isinstance(fieldid, int):
+        field = (targetdb.Field.select()
+                               .where((targetdb.Field.field_id == fieldid) &
+                                      (targetdb.Field.version == verpk)))
+        fieldpk = field[0].pk
+    else:
+        fieldpk = fieldid[0].pk
+
+    designToFieldDB = targetdb.DesignToField.create(design=design_id,
+                                                    field=fieldpk,
+                                                    exposure=exposure,
+                                                    field_exposure=field_exposure)
+    designToFieldDB.save()
+
+
+def make_design_assignments_targetdb(plan, fieldid, exposure, field_exposure,
                                      desmode_label,
                                      design_ids, robotID, holeID,
                                      obsWavelength,
@@ -283,6 +366,10 @@ def make_design_assignments_targetdb(plan, fieldid, exposure,
     exposure: int
         The exposure of this set of designs. 0th indexed
 
+    field_exposure: int
+        The exposure of this set of designs as listed in the
+        robostrategy design file. 0th indexed
+
     desmode_label: str
         DesignMode labe for the design.
 
@@ -377,15 +464,16 @@ def make_design_assignments_targetdb(plan, fieldid, exposure,
     assign_hash = assignment_hash(design_ids[robotID != -1],
                                   holeID[robotID != -1])
 
-    designDB = targetdb.Design.create(field=fieldpk,
-                                      exposure=exposure,
-                                      design_mode=desmode_label,
+    designDB = targetdb.Design.create(design_mode=desmode_label,
                                       mugatu_version=mugatu_version,
                                       run_on=datetime.datetime.now(),
                                       assignment_hash=assign_hash)
     # save row
     designDB.save()
 
+    # add the designToField entry
+    make_designToField(designDB.design_id, fieldid, exposure, field_exposure)
+
     # add the assignments for the design to the assignment database
     rows = []
     for j in range(len(robotID)):
